Overview
========

Razorback main features are

  - loading MT time-series data
  
    - metronix (ats files)
    - more to come
  
  - exploring a complete survey
  - robust estimate of MT impedance


Razorback has been presented at the `MTNet webinars`_.
The `slides`_ and `video`_ of the live demo are available there.


.. _MTNet webinars: http://mtnet.info/EMinars/EMinars.html
.. _slides: http://mtnet.info/EMinars/20210127_WawrzyniakSmai_EMinar.pdf
.. _video: http://mtnet.info/EMinars/20210127_WawrzyniakSmai_EMinar.mp4
